package gov.anl.aps.dm.common.exceptions;

import gov.anl.aps.dm.common.constants.DmStatus;
import org.apache.log4j.Logger;

/**
 * DM exception factory class.
 *
 */
public class DmExceptionFactory {

    private static final Logger logger
            = Logger.getLogger(DmExceptionFactory.class.getName());

    /**
     * Generate DM exception.
     *
     * @param type exception type
     * @param code exception code
     * @param error exception error message
     * @return generated DM exception
     */
    public static DmException generateDmException(String type, int code, String error) {
        DmException exc = new DmException();
        try {
            String fullType = "gov.anl.aps.dm.common.exceptions." + type;
            // Having trouble getting code below to work in all cases, so
            // use code for now.
            // exc = (DmException) Class.forName(fullType).newInstance();
            switch (code) {

                case DmStatus.DM_AUTHORIZATION_ERROR:
                    exc = new AuthorizationError();
                    break;
                case DmStatus.DM_COMMUNICATION_ERROR:
                    exc = new CommunicationError();
                    break;
                case DmStatus.DM_CONFIGURATION_ERROR:
                    exc = new ConfigurationError();
                    break;
                case DmStatus.DM_INTERNAL_ERROR:
                    exc = new InternalError();
                    break;
               case DmStatus.DM_DB_ERROR:
                    exc = new DbError();
                    break;
                case DmStatus.DM_INVALID_ARGUMENT:
                    exc = new InvalidArgument();
                    break;
                case DmStatus.DM_INVALID_REQUEST:
                    exc = new InvalidRequest();
                    break;
                case DmStatus.DM_INVALID_SESSION:
                    exc = new InvalidSession();
                    break;
                case DmStatus.DM_OBJECT_ALREADY_EXISTS:
                    exc = new ObjectAlreadyExists();
                    break;
                case DmStatus.DM_OBJECT_NOT_FOUND:
                    exc = new ObjectNotFound();
                    break;
                case DmStatus.DM_INVALID_OBJECT_STATE:
                    exc = new InvalidObjectState();
                    break;
                case DmStatus.DM_TIMEOUT_ERROR:
                    exc = new TimeoutError();
                    break;                    
                default:
                    exc = (DmException) Class.forName(fullType).newInstance();
            }
        } catch (ClassNotFoundException | IllegalAccessException | InstantiationException ex) {
            String err = "Cannot generate exception of type " + type + ": " + ex;
            logger.error(err);
        }
        exc.setErrorMessage(error);
        return exc;
    }

    /**
     * Throw DM exception.
     *
     * @param type exception type
     * @param code exception code
     * @param error exception error message
     * @throws DmException generated DM exception whenever this method is
     * called
     */
    public static void throwDmException(String type, int code, String error) throws DmException {
        DmException exc = generateDmException(type, code, error);
        throw exc;
    }
}
