#!/usr/bin/env python

from dm.common.cli.dmCli import DmCli
from dm.common.exceptions.invalidRequest import InvalidRequest
from dm.common.utility.configurationManager import ConfigurationManager

class ApsBeamlineCli(DmCli):
    """ Base APS beamline cli class. """

    def __init__(self, validArgCount=0):
        DmCli.__init__(self, validArgCount)

        configManager = ConfigurationManager.getInstance()
        self.allowedExperimentTypes = configManager.getAllowedExperimentTypes()
        allowedExperimentTypesHelp = ''
        if self.allowedExperimentTypes:
            allowedExperimentTypesHelp = ' Allowed types: %s' % self.allowedExperimentTypes
        self.stationName = configManager.getStationName()
        self.beamlineName = configManager.getBeamlineName()
        self.beamlineManagers = configManager.getBeamlineManagers()
        self.dsServiceHost = configManager.getDsWebServiceHost()
        self.dsServicePort = configManager.getDsWebServicePort()
        self.daqServiceHost = configManager.getDaqWebServiceHost()
        self.daqServicePort = configManager.getDaqWebServicePort()
        self.serviceProtocol = configManager.getWebServiceProtocol()

        loginGroup = 'Login Options'
        self.addOptionGroup(loginGroup, None)
        self.addOptionToGroup(loginGroup, '', '--login-file', dest='loginFile', help='DM login file, contains "<dm username>|<dm password>" pair. It may be specified using DM_LOGIN_FILE environment variable.')
        self.addOptionToGroup(loginGroup, '', '--bss-login-file', dest='bssLoginFile', help='BSS login file, contains "<bss username>|<bss password>" pair. It may be specified via environment variable DM_BSS_LOGIN_FILE.')

    def parseArgs(self, usage=None):
        DmCli.parseArgs(self, usage)
        (self.loginUsername,self.loginPassword) = self.parseLoginFile(self.getLoginFile())
        self.bssLoginFile = self.getBssLoginFile()
        return (self.options, self.args)

    def getLoginFile(self):
        if not self.options.loginFile:
            return ConfigurationManager.getInstance().getLoginFile()
        return self.options.loginFile

    def getBssLoginFile(self):
        if not self.options.bssLoginFile:
            return ConfigurationManager.getInstance().getBssLoginFile()
        return self.options.bssLoginFile

    def getStationName(self):
        return self.stationName

    def parseLoginFile(self,loginFile):
        username = None
        password = None
        try:
            # Assume form <username>|<password>
            if loginFile:
                tokenList = open(loginFile).readline().split('|')
                if len(tokenList) == 2:
                    username = tokenList[0].strip()
                    password = tokenList[1].strip()
        except:
            # Ignore invalid login file
            pass
        return (username,password)

    def checkCredentials(self):
        if not self.hasCredentials():
            raise InvalidRequest('DM login credentials are not specified.')
        if not self.hasBssCredentials():
            raise InvalidRequest('BSS login credentials are not specified.')

    def hasCredentials(self):
        return (self.loginUsername != None and self.loginPassword != None)

    def hasBssCredentials(self):
        return self.bssLoginFile != None

#######################################################################
# Testing

if __name__ == '__main__':
    pass
