#!/usr/bin/env python

from dm.cat_web_service.api.datasetCatApi import DatasetCatApi
from dm.common.exceptions.invalidRequest import InvalidRequest
from catWebServiceSessionCli import CatWebServiceSessionCli

class GetExperimentDatasetsCli(CatWebServiceSessionCli):
    def __init__(self):
        CatWebServiceSessionCli.__init__(self, validArgCount=self.ANY_NUMBER_OF_POSITIONAL_ARGS)
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')

    def getExperimentName(self):
        return self.options.experimentName

    def runCommand(self):
        self.parseArgs(usage="""
    dm-get-experiment-datasets --experiment=EXPERIMENTNAME 
        [key1:value1, key2:value2, ...]

Description:
    Retrieve experiment datasets from the metadata catalog. Only those 
    datasets that match provided key/value metadata pairs will be returned. 
    If no specific metadata key/values are requested, all experiment datasets 
    will be returned. 
        """)
        self.checkArgs()
        api = DatasetCatApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        queryDict = self.splitArgsIntoDict()
        datasetMetadataList = api.getExperimentDatasets(self.getExperimentName(), queryDict)
        for datasetMetadata in datasetMetadataList:
            print datasetMetadata.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = GetExperimentDatasetsCli()
    cli.run()

