#!/usr/bin/env python

from dm.daq_web_service.api.experimentDaqApi import ExperimentDaqApi
from dm.common.exceptions.invalidRequest import InvalidRequest
from daqWebServiceSessionCli import DaqWebServiceSessionCli

class StopDaqCli(DaqWebServiceSessionCli):
    def __init__(self):
        DaqWebServiceSessionCli.__init__(self)
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')
        self.addOption('', '--data-directory', dest='dataDirectory', help='Experiment data directory URL.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')
        if self.options.dataDirectory is None:
            raise InvalidRequest('Experiment data directory must be provided.')

    def runCommand(self):
        self.parseArgs(usage="""
    dm-stop-daq --experiment=EXPERIMENTNAME --data-directory=DATADIRECTORY

Description:
    Stop DAQ for a given experiment and data directory.
        """)
        self.checkArgs()
        api = ExperimentDaqApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        daqInfo = api.stopDaq(self.getExperimentName(), self.getDataDirectory())
        print daqInfo.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = StopDaqCli()
    cli.run()

