#!/usr/bin/env python

from dm.common.exceptions.invalidRequest import InvalidRequest
from dm.ds_web_service.api.fileDsApi import FileDsApi
from dsWebServiceSessionCli import DsWebServiceSessionCli

class DownloadCli(DsWebServiceSessionCli):
    def __init__(self):
        DsWebServiceSessionCli.__init__(self)
        self.addOption('', '--experiment', dest='experimentName', help='Experiment name.')
        self.addOption('', '--relative-path', dest='experimentFilePath', default='', help='Experiment (relative) file path. If omitted, all experiment data will be downloaded.')
        self.addOption('', '--destination-directory', dest='destinationDirectory', default='.', help='Destination directory. If omitted, files will be downloaded to current directory.')

    def checkArgs(self):
        if self.options.experimentName is None:
            raise InvalidRequest('Experiment name must be provided.')

    def getExperimentName(self):
        return self.options.experimentName

    def getExperimentFilePath(self):
        return self.options.experimentFilePath

    def getDestinationDirectory(self):
        return self.options.destinationDirectory

    def runCommand(self):
        self.parseArgs(usage="""
    dm-download --experiment=EXPERIMENTNAME 
        [--relative-path=EXPERIMENTFILEPATH]
        [--destination-directory=DESTINATIONDIRECTORY]

Description:
    Downloads experiment files.
        """)
        self.checkArgs()
        api = FileDsApi(self.getLoginUsername(), self.getLoginPassword(), self.getServiceHost(), self.getServicePort(), self.getServiceProtocol())
        api.download(self.getExperimentName(), self.getExperimentFilePath(), self.getDestinationDirectory())
        #print fileMetadata.getDisplayString(self.getDisplayKeys(), self.getDisplayFormat())

#######################################################################
# Run command.
if __name__ == '__main__':
    cli = DownloadCli()
    cli.run()

